#if 0
cc -arch m68k -arch i386 -object -s -O mounted.c -o mounted
# /* cc -g mounted.c -o mounted */
# /* Any other compile command would also do */
exit 0
#endif

/*
mounted - make sure certain directories are mounted (if they will be
automounted) for the whole execution time of the specified program.

This is needed for some searching strategies or backups.

Examples:
- mounted /Net/* -e tar cf /dev/nrst0 /
  will also backup all mounted directories.
  IMPORTANT: The remote files will be archived under /private/Net/...
  	     since /Net contains are only "hot" (i.e. automounting by
	     dereferencing) soft links. Doing a 
  tar cf /dev/nrst0 /private/Net/*
	     will not automount the directories, so they will not be
	     backed up if they are not already mounted and if the
	     directory would be unmounted (because of they are not
	     accessed for a certain amount of time) while the backup
	     takes place, they would not be remounted when tar tried
	     to access them afterwards.

Written 1993 Marcel Waldvogel, Uptime Object Factory Inc.
This source is hereby released to the public domain.
*/

#include <libc.h>
void main(int argc, char *argv[])
{
  int arg, fd;

  if (argc == 1)
  {
    printf("Usage: %s: directories ... [ -e command [ parameters ] ]\n",
             argv[0]);
    printf("  Keeps directories mounted while command is running.\n");
    printf("  If no command is given, keeps directories mounted forever,\n");
    printf("  i.e. until it is killed.\n");
  }
  
  arg = 1;
  while (arg < argc && strcmp(argv[arg], "-e") != 0)
  {
    fd = open(argv[arg], 0, 0);
    if (fd < 0)
    {
      perror(argv[arg]);
      exit(1);
    }
    arg++;
  }
  /* Do we have some program to execute? */
  if (arg == argc)
  {
    /* No, sleep forever, keeping the directories mounted */
    while (1)
      sleep(3600);
  }
  else
  {
    /* Yes, launch that program */
    execvp(argv[arg + 1], &argv[arg + 1]);
    /* If we return, something has gone wrong */
    perror(argv[arg + 1]);
  }
}
